News
====

0.2
---
**release date:** 2012-03-24
* Add some documentation
* Small code clean up
* Improve setup.py
* Make enzyme usable in place (even if not in sys.path)

0.1
---
**release date:** 2011-12-04
* Initial release
* Add some unittests
* Remove any dependency
* Keep only video parsers
* Fork Freevo's kaa.metadata module (many thanks to its authors)
